@@ -24,7 +24,6 @@
 
 #include <time.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
 
 #include <gconf/gconf-engine.h>
 #include <gconf/gconf-client.h>
@@ -1175,6 +1174,23 @@ find_window_at_pointer (GSManager *manager)
         return window;
 }
 
+void
+gs_manager_show_message (GSManager  *manager,
+                         const char *summary,
+                         const char *body,
+                         const char *icon)
+{
+        GSWindow *window;
+
+        g_return_if_fail (GS_IS_MANAGER (manager));
+
+        /* Find the GSWindow that contains the pointer */
+        window = find_window_at_pointer (manager);
+        gs_window_show_message (window, summary, body, icon);
+
+        gs_manager_request_unlock (manager);
+}
+
 static gboolean
 manager_maybe_grab_window (GSManager *manager,
                            GSWindow  *window)
@@ -1474,24 +1490,10 @@ on_screen_monitors_changed (GdkScreen *screen,
                   n_monitors);
 
         if (n_monitors > n_windows) {
-
-                /* Tear down unlock dialog in case we want to move it
-                 * to a new monitor
-                 */
-                l = manager->priv->windows;
-                while (l != NULL) {
-                        gs_window_cancel_unlock_request (GS_WINDOW (l->data));
-                        l = l->next;
-                }
-
                 /* add more windows */
                 for (i = n_windows; i < n_monitors; i++) {
                         gs_manager_create_window_for_monitor (manager, screen, i);
                 }
-
-                /* And put unlock dialog up where ever it's supposed to be
-                 */
-                gs_manager_request_unlock (manager);
         } else {
 
                 gdk_x11_grab_server ();
